'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var React = require('react');
var client = require('@apollo/client');
var mock = require('@graphql-tools/mock');
var testing = require('@apollo/client/testing');
var graphql = require('graphql');

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

function _objectWithoutPropertiesLoose(source, excluded) {
  if (source == null) return {};
  var target = {};
  var sourceKeys = Object.keys(source);
  var key, i;

  for (i = 0; i < sourceKeys.length; i++) {
    key = sourceKeys[i];
    if (excluded.indexOf(key) >= 0) continue;
    target[key] = source[key];
  }

  return target;
}

function delay(ms) {
  return new Promise(function (resolve) {
    setTimeout(function () {
      resolve();
    }, ms);
  });
}

function createMockLink(schema, rootValue, context, options) {
  var _ref, _options;

  if (rootValue === void 0) {
    rootValue = {};
  }

  if (context === void 0) {
    context = {};
  }

  if (options === void 0) {
    options = {};
  }

  var delayMs = (_ref = (_options = options) === null || _options === void 0 ? void 0 : _options.delay) !== null && _ref !== void 0 ? _ref : 0;
  return new client.ApolloLink(function (operation) {
    return new client.Observable(function (observer) {
      var query = operation.query,
          operationName = operation.operationName,
          variables = operation.variables;
      delay(delayMs).then(function () {
        return graphql.graphql(schema, graphql.print(query), rootValue, context, variables, operationName);
      }).then(function (result) {
        var _result$errors;

        var originalError = result === null || result === void 0 ? void 0 : (_result$errors = result.errors) === null || _result$errors === void 0 ? void 0 : _result$errors[0].originalError;

        if (originalError) {
          // @ts-ignore
          var graphQLErrors = originalError === null || originalError === void 0 ? void 0 : originalError.graphQLErrors;

          if (graphQLErrors) {
            observer.next({
              errors: graphQLErrors
            });
          } // @ts-ignore


          var networkError = originalError.networkError;

          if (networkError) {
            observer.error(networkError);
          }
        } else {
          observer.next(result);
        }

        observer.complete();
      })["catch"](observer.error.bind(observer));
    });
  });
}

function createErrorLink(graphQLError) {
  return new client.ApolloLink(function () {
    return new client.Observable(function (observer) {
      delay(100).then(function () {
        observer.next({
          errors: createGraphQLErrorMessage(graphQLError)
        });
        observer.complete();
      })["catch"](observer.error.bind(observer));
    });
  });
}
function createLoadingLink() {
  return new client.ApolloLink(function () {
    return new client.Observable(function () {});
  });
}
function createApolloClient(_ref2) {
  var mocks = _ref2.mocks,
      _ref2$delay = _ref2.delay,
      delay = _ref2$delay === void 0 ? 0 : _ref2$delay,
      _ref2$cacheOptions = _ref2.cacheOptions,
      cacheOptions = _ref2$cacheOptions === void 0 ? {} : _ref2$cacheOptions,
      _ref2$clientOptions = _ref2.clientOptions,
      clientOptions = _ref2$clientOptions === void 0 ? {} : _ref2$clientOptions,
      _ref2$links = _ref2.links,
      links = _ref2$links === void 0 ? function () {
    return [];
  } : _ref2$links,
      _ref2$addTypename = _ref2.addTypename,
      addTypename = _ref2$addTypename === void 0 ? false : _ref2$addTypename;
  var mockLink;

  if (!Array.isArray(mocks)) {
    var apolloLinkOptions = {};
    var resolvers = mocks.resolvers,
        introspectionResult = mocks.introspectionResult,
        rootValue = mocks.rootValue,
        context = mocks.context;
    var schema = graphql.buildClientSchema(introspectionResult);
    var schemaWithMocks = mock.addMocksToSchema({
      schema: schema,
      resolvers: resolvers
    });

    if (delay) {
      apolloLinkOptions.delay = delay;
    }

    mockLink = createMockLink(schemaWithMocks, rootValue, context, apolloLinkOptions);
  } else {
    mockLink = new testing.MockLink(mocks, addTypename);
  }

  var cache = new client.InMemoryCache(_extends({}, cacheOptions, {
    addTypename: addTypename
  }));
  return new client.ApolloClient(_extends({
    cache: cache,
    link: client.ApolloLink.from([].concat(links(cache), [mockLink]))
  }, clientOptions));
}
function createGraphQLErrorMessage(graphQLError) {
  if (graphQLError) {
    return typeof graphQLError === 'string' ? [new graphql.GraphQLError(graphQLError)] : graphQLError;
  }

  return [new graphql.GraphQLError('Unspecified error from ErrorProvider.')];
}
function createMocks(query, _ref3) {
  var variables = _ref3.variables,
      data = _ref3.data,
      newData = _ref3.newData,
      graphqlErrors = _ref3.graphqlErrors,
      error = _ref3.error,
      _ref3$delay = _ref3.delay,
      delay = _ref3$delay === void 0 ? 0 : _ref3$delay;
  return [_extends({
    request: {
      query: query,
      variables: variables
    }
  }, !error ? {
    result: _extends({
      data: data
    }, graphqlErrors ? {
      errors: createGraphQLErrorMessage(graphqlErrors)
    } : {})
  } : {}, {
    error: error,
    newData: newData,
    delay: delay
  })];
}

var ApolloMockedProvider = function ApolloMockedProvider(_ref) {
  var children = _ref.children,
      _ref$Provider = _ref.Provider,
      Provider = _ref$Provider === void 0 ? client.ApolloProvider : _ref$Provider,
      rest = _objectWithoutPropertiesLoose(_ref, ["children", "Provider"]);

  var client$1 = createApolloClient(rest);
  return React.createElement(Provider, {
    client: client$1
  }, children);
};

var ApolloLoadingProvider = function ApolloLoadingProvider(_ref) {
  var _ref$Provider = _ref.Provider,
      Provider = _ref$Provider === void 0 ? client.ApolloProvider : _ref$Provider,
      children = _ref.children;
  var client$1 = new client.ApolloClient({
    link: createLoadingLink(),
    cache: new client.InMemoryCache()
  });
  return React.createElement(Provider, {
    client: client$1
  }, children);
};

var ApolloErrorProvider = function ApolloErrorProvider(_ref) {
  var children = _ref.children,
      graphQLError = _ref.graphQLError,
      _ref$Provider = _ref.Provider,
      Provider = _ref$Provider === void 0 ? client.ApolloProvider : _ref$Provider;
  var client$1 = new client.ApolloClient({
    link: createErrorLink(graphQLError),
    cache: new client.InMemoryCache()
  });
  return React.createElement(Provider, {
    client: client$1
  }, children);
};

exports.ApolloErrorProvider = ApolloErrorProvider;
exports.ApolloLoadingProvider = ApolloLoadingProvider;
exports.ApolloMockedProvider = ApolloMockedProvider;
exports.createApolloClient = createApolloClient;
exports.createErrorLink = createErrorLink;
exports.createGraphQLErrorMessage = createGraphQLErrorMessage;
exports.createLoadingLink = createLoadingLink;
exports.createMocks = createMocks;
//# sourceMappingURL=apollo-mocked.cjs.development.js.map
